==> huhk-1.9.1.tar.gz: huhk-1.9.1/service/app_a/asserts/content/asserts_content_commonquestion.py <==
import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_commonquestion import SqlsContentCommonquestion


class AssertsContentCommonquestion(SqlsContentCommonquestion):
    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_updatestatus(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_updatestatus(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["status", "essayId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_update(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["title", "content", "essayId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_updaterank(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_updaterank(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId", "rank"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_delete(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_delete(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_list(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_list(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_publishlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_publishlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_add(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_add(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["title", "content", "essayId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_createid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_createid(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_info(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_info(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        assert True, "数据比较不一致"

==> huhk-1.9.6.tar.gz: huhk-1.9.6/service/app_a/asserts/content/asserts_content_commonquestion.py <==
import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_commonquestion import SqlsContentCommonquestion


class AssertsContentCommonquestion(SqlsContentCommonquestion):
    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_updatestatus(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_updatestatus(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["status", "essayId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_update(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["content", "title", "essayId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_updaterank(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_updaterank(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["rank", "essayId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_delete(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_delete(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_list(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_list(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_publishlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_publishlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_add(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_add(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["content", "title", "essayId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_createid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_createid(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_info(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_info(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        assert True, "数据比较不一致"
